#ifdef __CINT__

#pragma link off all globals;
#pragma link off all classes;
#pragma link off all functions;

#pragma link C++ nestedclass;

#pragma link C++ namespace Gfitter;

#pragma link C++ class Gfitter::GObject; 
#pragma link C++ class Gfitter::GParameter; 
#pragma link C++ class Gfitter::GResultBase; 
#pragma link C++ class Gfitter::GResultEval; 
#pragma link C++ class Gfitter::GResultScan1d; 
#pragma link C++ class Gfitter::GResultContainer; 
#pragma link C++ class Gfitter::GController;
#pragma link C++ class Gfitter::GTheoryBase;
#pragma link C++ class Gfitter::GTheory;
#pragma link C++ class Gfitter::GAuxTheory;
#pragma link C++ class Gfitter::GMinuitFitter;
#pragma link C++ class Gfitter::GDataBase;
#pragma link C++ class Gfitter::GData;
#pragma link C++ class Gfitter::GDataCurve;
#pragma link C++ class Gfitter::GCorrGaussGen;
#pragma link C++ class Gfitter::GInterval;
#pragma link C++ class Gfitter::GGSLMinimizer;
#pragma link C++ class Gfitter::GRandomSimplex;
#pragma link C++ class Gfitter::GCornerSimplex;
#pragma link C++ class Gfitter::GWorkspace;
#pragma link C++ class Gfitter::GMultiNestFitter;

#pragma link C++ function Gfitter::ground;
#endif
